@@ -1,26 +1,26 @@
 /*	MikMod sound library
-	(c) 1998, 1999 Miodrag Vallat and others - see file AUTHORS for
+	(c) 1998, 1999, 2000 Miodrag Vallat and others - see file AUTHORS for
 	complete list.
 
 	This library is free software; you can redistribute it and/or modify
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 	02111-1307, USA.
 */
-  
+
 /*==============================================================================
 
-  $Id: drv_hp.c,v 1.26 1999/06/28 03:00:05 miod Exp $
+  $Id: drv_hp.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Driver for output to HP 9000 series /dev/audio
 
@@ -36,6 +36,10 @@
 #include "config.h"
 #endif
 
+#include "mikmod_internals.h"
+
+#ifdef DRV_HP
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -45,8 +49,6 @@
 #include <stdlib.h>
 #include <sys/audio.h>
 
-#include <mikmod_internals.h>
-
 #define BUFFERSIZE 15
 
 static	int fd=-1;
@@ -78,17 +80,17 @@ static BOOL HP_IsThere(void)
 {
 	int fd;
 
-	if((fd=open("/dev/audio",O_WRONLY))>0) {
+	if((fd=open("/dev/audio",O_WRONLY))>=0) {
 		close(fd);
 		return 1;
 	}
 	return (errno==EACCES?1:0);
 }
 
-static BOOL HP_Init(void)
+static int HP_Init(void)
 {
 	int flags;
-	
+
 	if (!(md_mode&DMODE_16BITS)) {
 		_mm_errno=MMERR_16BIT_ONLY;
 		return 1;
@@ -108,24 +110,24 @@ static BOOL HP_Init(void)
 		_mm_errno=MMERR_NON_BLOCK;
 		return 1;
 	}
-	
+
 	if (ioctl(fd,AUDIO_SET_DATA_FORMAT,AUDIO_FORMAT_LINEAR16BIT)) {
 		_mm_errno=MMERR_HP_SETSAMPLESIZE;
 		return 1;
 	}
-	
+
 	if (ioctl(fd,AUDIO_SET_SAMPLE_RATE,md_mixfreq)) {
 		_mm_errno=MMERR_HP_SETSPEED;
 		return 1;
 	}
-	
+
 	if (ioctl(fd,AUDIO_SET_CHANNELS,(md_mode&DMODE_STEREO)?2:1)) {
 		_mm_errno=MMERR_HP_CHANNELS;
 		return 1;
 	}
-	
+
 	if (ioctl(fd,AUDIO_SET_OUTPUT,
-	             headphone?AUDIO_OUT_HEADPHONE:AUDIO_OUT_SPEAKER)) {
+		     headphone?AUDIO_OUT_HEADPHONE:AUDIO_OUT_SPEAKER)) {
 		_mm_errno=MMERR_HP_AUDIO_OUTPUT;
 		return 1;
 	}
@@ -136,7 +138,7 @@ static BOOL HP_Init(void)
 	}
 
 	if (!(audiobuffer=(SBYTE*)_mm_malloc(buffersize))) return 1;
-	
+
 	return VC_Init();
 }
 
@@ -159,7 +161,7 @@ static void HP_Update(void)
 	write(fd,audiobuffer,VC_WriteBytes(audiobuffer,buffersize));
 }
 
-MDRIVER drv_hp={
+MIKMODAPI MDRIVER drv_hp={
 	NULL,
 	"HP-UX Audio",
 	"HP-UX Audio driver v1.3",
@@ -193,4 +195,11 @@ MDRIVER drv_hp={
 	VC_VoiceRealVolume
 };
 
+#else
+
+MISSING(drv_hp);
+
+#endif
+
 /* ex:set ts=4: */
+
