@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: drv_raw.c,v 1.2 2004/01/21 17:29:32 raph Exp $
+  $Id: drv_raw.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Driver for output to a file called MUSIC.RAW
 
@@ -30,18 +30,21 @@
 #include "config.h"
 #endif
 
+#ifdef DRV_RAW
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#ifdef HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
 
 #ifndef macintosh
 #include <sys/types.h>
 #include <sys/stat.h>
 #endif
 
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #include "mikmod_internals.h"
 
 #define BUFFERSIZE 32768
@@ -51,7 +54,7 @@
 #define O_BINARY 0
 #endif
 
-#if defined(WIN32) && !defined(__MWERKS__)
+#if defined(_WIN32) && !defined(__MWERKS__)
 #define open _open
 #endif
 
@@ -74,33 +77,36 @@ static BOOL RAW_IsThere(void)
 	return 1;
 }
 
-static BOOL RAW_Init(void)
+static int RAW_Init(void)
 {
-#if defined unix || (defined __APPLE__ && defined __MACH__)
+#if (MIKMOD_UNIX)
 	if(!MD_Access(filename?filename:FILENAME)) {
 		_mm_errno=MMERR_OPENING_FILE;
 		return 1;
 	}
 #endif
 
-	if((rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY
 #if !defined(macintosh) && !defined(__MWERKS__)
-	                ,S_IREAD|S_IWRITE
+	rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY,S_IREAD|S_IWRITE);
+#else
+	rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY);
 #endif
-	               ))<0) {
+	if(rawout<0) {
 		_mm_errno=MMERR_OPENING_FILE;
 		return 1;
 	}
 	md_mode|=DMODE_SOFT_MUSIC|DMODE_SOFT_SNDFX;
 
 	if (!(audiobuffer=(SBYTE*)_mm_malloc(BUFFERSIZE))) {
-		close(rawout);unlink(filename?filename:FILENAME);
+		close(rawout);
+		unlink(filename?filename:FILENAME);
 		rawout=-1;
 		return 1;
 	}
 
 	if ((VC_Init())) {
-		close(rawout);unlink(filename?filename:FILENAME);
+		close(rawout);
+		unlink(filename?filename:FILENAME);
 		rawout=-1;
 		return 1;
 	}
@@ -122,14 +128,15 @@ static void RAW_Update(void)
 	write(rawout,audiobuffer,VC_WriteBytes(audiobuffer,BUFFERSIZE));
 }
 
-static BOOL RAW_Reset(void)
+static int RAW_Reset(void)
 {
 	close(rawout);
-	if((rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY
 #if !defined(macintosh) && !defined(__MWERKS__)
-	                ,S_IREAD|S_IWRITE
+	rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY,S_IREAD|S_IWRITE);
+#else
+	rawout=open(filename?filename:FILENAME,O_RDWR|O_TRUNC|O_CREAT|O_BINARY);
 #endif
-	               ))<0) {
+	if(rawout<0) {
 		_mm_errno=MMERR_OPENING_FILE;
 		return 1;
 	}
@@ -171,4 +178,10 @@ MIKMODAPI MDRIVER drv_raw={
 	VC_VoiceRealVolume
 };
 
+#else
+#include "mikmod_internals.h"
+MISSING(drv_raw);
+
+#endif
+
 /* ex:set ts=4: */
