@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: drv_wav.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: drv_wav.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Driver for output to a file called MUSIC.WAV
 
@@ -32,6 +32,8 @@
 
 #include "mikmod_internals.h"
 
+#ifdef DRV_WAV
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -53,17 +55,20 @@ static	CHAR *filename=NULL;
 
 static void putheader(void)
 {
+	ULONG rflen = 36;
+	rflen += dumpsize;
+
 	_mm_fseek(wavout,0,SEEK_SET);
 	_mm_write_string("RIFF",wavout);
-	_mm_write_I_ULONG(dumpsize+44,wavout);
+	_mm_write_I_ULONG(rflen,wavout);
 	_mm_write_string("WAVEfmt ",wavout);
 	_mm_write_I_ULONG(16,wavout);	/* length of this RIFF block crap */
 
-	_mm_write_I_UWORD(1, wavout);	/* microsoft format type */
+	_mm_write_I_UWORD(1, wavout);	/* WAVE_FORMAT_PCM :1 */
 	_mm_write_I_UWORD((md_mode&DMODE_STEREO)?2:1,wavout);
 	_mm_write_I_ULONG(md_mixfreq,wavout);
-	_mm_write_I_ULONG(md_mixfreq*((md_mode&DMODE_STEREO)?2:1)*
-	                  ((md_mode&DMODE_16BITS)?2:1),wavout);
+	_mm_write_I_ULONG(md_mixfreq *	((md_mode&DMODE_STEREO)?2:1) *
+					((md_mode&DMODE_16BITS)?2:1), wavout);
 	/* block alignment (8/16 bit) */
 	_mm_write_I_UWORD(((md_mode&DMODE_16BITS)?2:1)* 
 	                  ((md_mode&DMODE_STEREO)?2:1),wavout);
@@ -87,9 +92,9 @@ static BOOL WAV_IsThere(void)
 	return 1;
 }
 
-static BOOL WAV_Init(void)
+static int WAV_Init(void)
 {
-#if defined unix || (defined __APPLE__ && defined __MACH__)
+#if (MIKMOD_UNIX)
 	if (!MD_Access(filename?filename:FILENAME)) {
 		_mm_errno=MMERR_OPENING_FILE;
 		return 1;
@@ -148,7 +153,15 @@ static void WAV_Update(void)
 	ULONG done;
 
 	done=VC_WriteBytes(audiobuffer,BUFFERSIZE);
-	_mm_write_UBYTES(audiobuffer,done,wavout);
+
+	if (md_mode & DMODE_16BITS) {
+	/* <AWE> Fix for 16bit samples on big endian systems: Just swap
+	 * bytes via "_mm_write_I_UWORDS ()" if we have 16 bit output.	*/
+		_mm_write_I_UWORDS((UWORD *) audiobuffer,done>>1,wavout);
+	}
+	else {
+		_mm_write_UBYTES(audiobuffer,done,wavout);
+	}
 	dumpsize+=done;
 }
 
@@ -186,4 +199,10 @@ MIKMODAPI MDRIVER drv_wav={
 	VC_VoiceRealVolume
 };
 
+#else
+
+MISSING(drv_wav);
+
+#endif
+
 /* ex:set ts=4: */
