@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: load_669.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: load_669.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Composer 669 module loader
 
@@ -49,7 +49,7 @@ extern int fprintf(FILE *, const char *, ...);
 /*========== Module structure */
 
 /* header */
-typedef struct S69HEADER {   
+typedef struct S69HEADER {
 	UBYTE	marker[2];
 	CHAR	message[108];
 	UBYTE	nos;
@@ -88,7 +88,7 @@ static	CHAR* S69_Version[]={
 
 /*========== Loader code */
 
-BOOL S69_Test(void)
+static BOOL S69_Test(void)
 {
 	UBYTE buf[0x80];
 
@@ -122,7 +122,7 @@ BOOL S69_Test(void)
 	return 1;
 }
 
-BOOL S69_Init(void)
+static BOOL S69_Init(void)
 {
 	if(!(s69pat=(S69NOTE *)_mm_malloc(64*8*sizeof(S69NOTE)))) return 0;
 	if(!(mh=(S69HEADER *)_mm_malloc(sizeof(S69HEADER)))) return 0;
@@ -130,7 +130,7 @@ BOOL S69_Init(void)
 	return 1;
 }
 
-void S69_Cleanup(void)
+static void S69_Cleanup(void)
 {
 	_mm_free(s69pat);
 	_mm_free(mh);
@@ -142,7 +142,7 @@ static BOOL S69_LoadPatterns(void)
 	UBYTE note,inst,vol,effect,lastfx,lastval;
 	S69NOTE *cur;
 	int tracks=0;
-	
+
 	if(!AllocPatterns()) return 0;
 	if(!AllocTracks()) return 0;
 
@@ -226,7 +226,7 @@ static BOOL S69_LoadPatterns(void)
 						case 5: /* set speed */
 							if (effect)
 								UniPTEffect(0xf,effect);
-							else 
+							else
 							  if(mh->marker[0]!=0x69) {
 #ifdef MIKMOD_DEBUG
 								fprintf(stderr,"\r669: unsupported super fast tempo at pat=%d row=%d chan=%d\n",
@@ -245,7 +245,7 @@ static BOOL S69_LoadPatterns(void)
 	return 1;
 }
 
-BOOL S69_Load(BOOL curious)
+static BOOL S69_Load(BOOL curious)
 {
 	int i;
 	SAMPLE *current;
@@ -342,7 +342,7 @@ BOOL S69_Load(BOOL curious)
 	return 1;
 }
 
-CHAR *S69_LoadTitle(void)
+static CHAR *S69_LoadTitle(void)
 {
 	CHAR s[36];
 
