@@ -1,17 +1,17 @@
 /*	MikMod sound library
-	(c) 1998, 1999 Miodrag Vallat and others - see file AUTHORS for
-	complete list.
+	(c) 1998, 1999, 2000, 2001, 2002 Miodrag Vallat and others - see file
+	AUTHORS for complete list.
 
 	This library is free software; you can redistribute it and/or modify
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: load_far.c,v 1.28 1999/06/28 03:00:05 miod Exp $
+  $Id: load_far.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Farandole (FAR) module loader
 
@@ -30,9 +30,21 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#include <stdio.h>
+#ifdef HAVE_MEMORY_H
+#include <memory.h>
+#endif
 #include <string.h>
 
-#include <mikmod_internals.h>
+#include "mikmod_internals.h"
+
+#ifdef SUNOS
+extern int fprintf(FILE *, const char *, ...);
+#endif
 
 /*========== Module structure */
 
@@ -84,7 +96,7 @@ static	unsigned char FARSIG[4+3]={'F','A','R',0xfe,13,10,26};
 
 /*========== Loader code */
 
-BOOL FAR_Test(void)
+static BOOL FAR_Test(void)
 {
 	UBYTE id[47];
 
@@ -93,7 +105,7 @@ BOOL FAR_Test(void)
 	return 1;
 }
 
-BOOL FAR_Init(void)
+static BOOL FAR_Init(void)
 {
 	if(!(mh1 = (FARHEADER1*)_mm_malloc(sizeof(FARHEADER1)))) return 0;
 	if(!(mh2 = (FARHEADER2*)_mm_malloc(sizeof(FARHEADER2)))) return 0;
@@ -102,15 +114,11 @@ BOOL FAR_Init(void)
 	return 1;
 }
 
-void FAR_Cleanup(void)
+static void FAR_Cleanup(void)
 {
-	if(mh1) free(mh1);
-	if(mh2) free(mh2);
-	if(pat) free(pat);
-
-	mh1=NULL;
-	mh2=NULL;
-	pat=NULL;
+	_mm_free(mh1);
+	_mm_free(mh2);
+	_mm_free(pat);
 }
 
 static UBYTE *FAR_ConvertTrack(FARNOTE* n,int rows)
@@ -129,6 +137,9 @@ static UBYTE *FAR_ConvertTrack(FARNOTE* n,int rows)
 				case 0x3: /* porta to note */
 					UniPTEffect(0x3,(n->eff&0xf)<<4);
 					break;
+				case 0x4: /* retrigger */
+					UniPTEffect(0x0e, 0x90 | (n->eff & 0x0f));
+					break;
 				case 0x5: /* set vibrato depth */
 					vibdepth=n->eff&0xf;
 					break;
@@ -141,6 +152,9 @@ static UBYTE *FAR_ConvertTrack(FARNOTE* n,int rows)
 				case 0x8: /* volume slide down */
 					UniPTEffect(0xa,n->eff&0xf);
 					break;
+				case 0xb: /* panning */
+					UniPTEffect(0xe,0x80|(n->eff&0xf));
+					break;
 				case 0xf: /* set speed */
 					UniPTEffect(0xf,n->eff&0xf);
 					break;
@@ -159,7 +173,7 @@ static UBYTE *FAR_ConvertTrack(FARNOTE* n,int rows)
 	return UniDup();
 }
 
-BOOL FAR_Load(BOOL curious)
+static BOOL FAR_Load(BOOL curious)
 {
 	int t,u,tracks=0;
 	SAMPLE *q;
@@ -187,11 +201,12 @@ BOOL FAR_Load(BOOL curious)
 	of.initspeed = mh1->speed;
 	of.inittempo = 80;
 	of.reppos    = 0;
+	of.flags    |= UF_PANNING;
 	for(t=0;t<16;t++) of.panning[t]=mh1->panning[t]<<4;
 
 	/* read songtext into comment field */
 	if(mh1->stlen)
-		if(!ReadComment(mh1->stlen)) return 0;
+		if (!ReadLinedComment(mh1->stlen, 66)) return 0;
 
 	/* try to read module header (second part) */
 	_mm_read_UBYTES(mh2->orders,256,modreader);
@@ -222,12 +237,14 @@ BOOL FAR_Load(BOOL curious)
 	if(!AllocPatterns()) return 0;
 
 	for(t=0;t<of.numpat;t++) {
-		UBYTE rows=0,tempo;
+		UBYTE rows=0;
+		UBYTE tempo;
 
 		memset(pat,0,256*16*4*sizeof(FARNOTE));
 		if(mh2->patsiz[t]) {
 			rows  = _mm_read_UBYTE(modreader);
 			tempo = _mm_read_UBYTE(modreader);
+			(void)tempo; /* unused */
 
 			crow = pat;
 			/* file often allocates 64 rows even if there are less in pattern */
@@ -268,7 +285,7 @@ BOOL FAR_Load(BOOL curious)
 	of.numins = 0;
 	for(t=0;t<64;t++)
 		if(smap[t>>3]&(1<<(t&7))) of.numins=t+1;
-	of.numsmp = of.numins;             
+	of.numsmp = of.numins;
 
 	/* alloc sample structs */
 	if(!AllocSamples()) return 0;
@@ -298,26 +315,26 @@ BOOL FAR_Load(BOOL curious)
 
 			q->seekpos    = _mm_ftell(modreader);
 			_mm_fseek(modreader,q->length,SEEK_CUR);
-		} else 
-			q->samplename = DupStr(NULL,0,0);
+		} else
+			q->samplename = strdup("");
 		q++;
 	}
 	return 1;
 }
 
-CHAR *FAR_LoadTitle(void)
+static CHAR *FAR_LoadTitle(void)
 {
 	CHAR s[40];
 
 	_mm_fseek(modreader,4,SEEK_SET);
 	if(!_mm_read_UBYTES(s,40,modreader)) return NULL;
-   
-	return(DupStr(s,40,1));
+
+	return (DupStr(s,40,1));
 }
 
 /*========== Loader information */
 
-MLOADER load_far={
+MIKMODAPI MLOADER load_far={
 	NULL,
 	"FAR",
 	"FAR (Farandole Composer)",
