@@ -1,17 +1,17 @@
 /*	MikMod sound library
-	(c) 1998, 1999 Miodrag Vallat and others - see file AUTHORS for
-	complete list.
+	(c) 1998, 1999, 2000, 2001, 2002 Miodrag Vallat and others - see file
+	AUTHORS for complete list.
 
 	This library is free software; you can redistribute it and/or modify
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: load_s3m.c,v 1.30 1999/06/28 03:00:05 miod Exp $
+  $Id: load_s3m.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   Screamtracker (S3M) module loader
 
@@ -30,9 +30,21 @@
 #include "config.h"
 #endif
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#include <stdio.h>
+#ifdef HAVE_MEMORY_H
+#include <memory.h>
+#endif
 #include <string.h>
 
-#include <mikmod_internals.h>
+#include "mikmod_internals.h"
+
+#ifdef SUNOS
+extern int fprintf(FILE *, const char *, ...);
+#endif
 
 /*========== Module structure */
 
@@ -88,6 +100,7 @@ typedef struct S3MNOTE {
 static S3MNOTE   *s3mbuf  = NULL; /* pointer to a complete S3M pattern */
 static S3MHEADER *mh      = NULL;
 static UWORD     *paraptr = NULL; /* parapointer array (see S3M docs) */
+static unsigned int tracker;	/* tracker id */
 
 /* tracker identifiers */
 #define NUMTRACKERS 4
@@ -96,7 +109,7 @@ static CHAR* S3M_Version[] = {
 	"Imago Orpheus x.xx (S3M format)",
 	"Impulse Tracker x.xx (S3M format)",
 	"Unknown tracker x.xx (S3M format)",
-	"Impulse Tracker 2.14p3 (S3M format)"
+	"Impulse Tracker 2.14p3 (S3M format)",
 	"Impulse Tracker 2.14p4 (S3M format)"
 };
 /* version number position in above array */
@@ -104,7 +117,7 @@ static int numeric[NUMTRACKERS]={14,14,16,16};
 
 /*========== Loader code */
 
-BOOL S3M_Test(void)
+static BOOL S3M_Test(void)
 {
 	UBYTE id[4];
 
@@ -114,7 +127,7 @@ BOOL S3M_Test(void)
 	return 0;
 }
 
-BOOL S3M_Init(void)
+static BOOL S3M_Init(void)
 {
 	if(!(s3mbuf=(S3MNOTE*)_mm_malloc(32*64*sizeof(S3MNOTE)))) return 0;
 	if(!(mh=(S3MHEADER*)_mm_malloc(sizeof(S3MHEADER)))) return 0;
@@ -124,19 +137,13 @@ BOOL S3M_Init(void)
 	return 1;
 }
 
-void S3M_Cleanup(void)
+static void S3M_Cleanup(void)
 {
-	if(s3mbuf) free(s3mbuf);
-	if(paraptr) free(paraptr);
-	if(poslookup) free(poslookup);
-	if(mh) free(mh);
-	if(origpositions) free(origpositions);
-
-	paraptr   = NULL;
-	s3mbuf    = NULL;
-	poslookup = NULL;
-	mh        = NULL;
-	origpositions = NULL;
+	_mm_free(s3mbuf);
+	_mm_free(paraptr);
+	_mm_free(poslookup);
+	_mm_free(mh);
+	_mm_free(origpositions);
 }
 
 /* Because so many s3m files have 16 channels as the set number used, but really
@@ -147,9 +154,9 @@ void S3M_Cleanup(void)
    global variable 'remap'
 
    NOTE: You must first seek to the file location of the pattern before calling
-         this procedure.
+   this procedure.
 
-   Returns 1 on fail.                                                         */
+   Returns 0 on fail. */
 static BOOL S3M_GetNumChannels(void)
 {
 	int row=0,flag,ch;
@@ -159,19 +166,19 @@ static BOOL S3M_GetNumChannels(void)
 
 		if(_mm_eof(modreader)) {
 			_mm_errno = MMERR_LOADING_PATTERN;
-			return 1;
+			return 0;
 		}
 
 		if(flag) {
 			ch=flag&31;
 			if(mh->channels[ch]<32) remap[ch] = 0;
-			if(flag&32) {_mm_read_UBYTE(modreader);_mm_read_UBYTE(modreader);}
-			if(flag&64) _mm_read_UBYTE(modreader);
-			if(flag&128){_mm_read_UBYTE(modreader);_mm_read_UBYTE(modreader);}
+			if(flag&32) {_mm_skip_BYTE(modreader);_mm_skip_BYTE(modreader);}
+			if(flag&64) _mm_skip_BYTE(modreader);
+			if(flag&128){_mm_skip_BYTE(modreader);_mm_skip_BYTE(modreader);}
 		} else row++;
 	}
-	return 0;
-}    
+	return 1;
+}
 
 static BOOL S3M_ReadPattern(void)
 {
@@ -201,8 +208,10 @@ static BOOL S3M_ReadPattern(void)
 				n->note=_mm_read_UBYTE(modreader);
 				n->ins=_mm_read_UBYTE(modreader);
 			}
-			if(flag&64)
+			if(flag&64) {
 				n->vol=_mm_read_UBYTE(modreader);
+				if (n->vol>64) n->vol=64;
+			}
 			if(flag&128) {
 				n->cmd=_mm_read_UBYTE(modreader);
 				n->inf=_mm_read_UBYTE(modreader);
@@ -234,13 +243,14 @@ static UBYTE* S3M_ConvertTrack(S3MNOTE* tr)
 		}
 		if(vol<255) UniPTEffect(0xc,vol);
 
-		S3MIT_ProcessCmd(tr[t].cmd,tr[t].inf,1);
+		S3MIT_ProcessCmd(tr[t].cmd,tr[t].inf,
+			tracker == 1 ? S3MIT_OLDSTYLE | S3MIT_SCREAM : S3MIT_OLDSTYLE);
 		UniNewline();
 	}
 	return UniDup();
 }
 
-BOOL S3M_Load(BOOL curious)
+static BOOL S3M_Load(BOOL curious)
 {
 	int t,u,track = 0;
 	SAMPLE *q;
@@ -273,6 +283,23 @@ BOOL S3M_Load(BOOL curious)
 		return 0;
 	}
 
+	/* then we can decide the module type */
+	tracker=mh->tracker>>12;
+	if((!tracker)||(tracker>=NUMTRACKERS))
+		tracker=NUMTRACKERS-1; /* unknown tracker */
+	else {
+		if(mh->tracker>=0x3217)
+			tracker=NUMTRACKERS+1; /* IT 2.14p4 */
+		else if(mh->tracker>=0x3216)
+			tracker=NUMTRACKERS; /* IT 2.14p3 */
+		else tracker--;
+	}
+	of.modtype = strdup(S3M_Version[tracker]);
+	if(tracker<NUMTRACKERS) {
+		of.modtype[numeric[tracker]] = ((mh->tracker>>8) &0xf)+'0';
+		of.modtype[numeric[tracker]+2] = ((mh->tracker>>4)&0xf)+'0';
+		of.modtype[numeric[tracker]+3] = ((mh->tracker)&0xf)+'0';
+	}
 	/* set module variables */
 	of.songname    = DupStr(mh->songname,28,0);
 	of.numpat      = mh->patnum;
@@ -281,9 +308,10 @@ BOOL S3M_Load(BOOL curious)
 	of.initspeed   = mh->initspeed;
 	of.inittempo   = mh->inittempo;
 	of.initvolume  = mh->mastervol<<1;
-	of.flags      |= UF_ARPMEM;
+	of.flags      |= UF_ARPMEM | UF_PANNING;
 	if((mh->tracker==0x1300)||(mh->flags&64))
 		of.flags|=UF_S3MSLIDES;
+	of.bpmlimit    = 32;
 
 	/* read the order data */
 	if(!AllocPositions(mh->ordnum)) return 0;
@@ -345,6 +373,11 @@ BOOL S3M_Load(BOOL curious)
 		_mm_read_string(s.sampname,28,modreader);
 		_mm_read_string(s.scrs,4,modreader);
 
+		/* ScreamTracker imposes a 64000 bytes (not 64k !) limit */
+		/* enforce it, if we'll use S3MIT_SCREAM in S3M_ConvertTrack() */
+		if (s.length > 64000 && tracker == 1)
+			s.length = 64000;
+
 		if(_mm_eof(modreader)) {
 			_mm_errno = MMERR_LOADING_SAMPLEINFO;
 			return 0;
@@ -353,8 +386,8 @@ BOOL S3M_Load(BOOL curious)
 		q->samplename = DupStr(s.sampname,28,0);
 		q->speed      = s.c2spd;
 		q->length     = s.length;
-		q->loopstart  = s.loopbeg>s.length?s.length:s.loopbeg;
-		q->loopend    = s.loopend>s.length?s.length:s.loopend;
+		q->loopstart  = s.loopbeg;
+		q->loopend    = s.loopend;
 		q->volume     = s.volume;
 		q->seekpos    = (((long)s.memsegh)<<16|s.memsegl)<<4;
 
@@ -374,43 +407,21 @@ BOOL S3M_Load(BOOL curious)
 	for(t=0;t<of.numpat;t++) {
 		/* seek to pattern position (+2 skip pattern length) */
 		_mm_fseek(modreader,(long)((paraptr[of.numins+t])<<4)+2,SEEK_SET);
-		if(S3M_GetNumChannels()) return 0;
-	}
-	/* only Imago Orpheus creates S3M with more than 16 channels */
-	if((of.numchn>16)&&(mh->tracker>>12!=2)) {
-		_mm_errno=MMERR_LOADING_HEADER;
-		return 0;
-	}
-
-	/* then we can decide the module type */
-	t=mh->tracker>>12;
-	if((!t)||(t>3))
-		t=NUMTRACKERS-1; /* unknown tracker */
-	else {
-		if(mh->tracker>=0x3217)
-			t=NUMTRACKERS+1; /* IT 2.14p4 */
-		else if(mh->tracker>=0x3217)
-			t=NUMTRACKERS; /* IT 2.14p3 */
-	}
-	of.modtype = strdup(S3M_Version[t-1]);
-	if(t<NUMTRACKERS) {
-		of.modtype[numeric[t-1]] = ((mh->tracker>>8) &0xf)+'0';
-		of.modtype[numeric[t-1]+2] = ((mh->tracker>>4)&0xf)+'0';
-		of.modtype[numeric[t-1]+3] = ((mh->tracker)&0xf)+'0';
+		if(!S3M_GetNumChannels()) return 0;
 	}
 
 	/* build the remap array  */
 	for(t=0;t<32;t++)
-		if(!remap[t]) 
+		if(!remap[t])
 			remap[t]=of.numchn++;
 
 	/* set panning positions after building remap chart! */
-	for(t=0;t<32;t++) 
+	for(t=0;t<32;t++)
 		if((mh->channels[t]<32)&&(remap[t]!=-1)) {
 			if(mh->channels[t]<8)
-				of.panning[remap[t]]=0x20;	/* 0x30 = std s3m val */
+				of.panning[remap[t]]=0x30;
 			else
-				of.panning[remap[t]]=0xd0;	/* 0xc0 = std s3m val */
+				of.panning[remap[t]]=0xc0;
 		}
 	if(mh->pantable==252)
 		/* set panning positions according to panning table (new for st3.2) */
@@ -434,7 +445,7 @@ BOOL S3M_Load(BOOL curious)
 	return 1;
 }
 
-CHAR *S3M_LoadTitle(void)
+static CHAR *S3M_LoadTitle(void)
 {
 	CHAR s[28];
 
@@ -446,7 +457,7 @@ CHAR *S3M_LoadTitle(void)
 
 /*========== Loader information */
 
-MLOADER load_s3m={
+MIKMODAPI MLOADER load_s3m={
 	NULL,
 	"S3M",
 	"S3M (Scream Tracker 3)",
