@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: load_uni.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: load_uni.c,v 1.1.1.1 2004/06/01 12:16:17 raph Exp $
 
   UNIMOD (libmikmod's and APlayer's internal module format) loader
 
@@ -94,21 +94,21 @@ static UNISMP05 *wh=NULL,*s=NULL;
 
 /*========== Loader code */
 
-static char* readstring(void)
+static char * readstring(void)
 {
-	char *s=NULL;
+	char *str=NULL;
 	UWORD len;
-	
+
 	len=_mm_read_I_UWORD(modreader);
 	if(len) {
-		s=_mm_malloc(len+1);
-		_mm_read_UBYTES(s,len,modreader);
-		s[len]=0;
+		str=_mm_malloc(len+1);
+		_mm_read_UBYTES(str,len,modreader);
+		str[len]=0;
 	}
-	return s;
+	return str;
 }
 
-BOOL UNI_Test(void)
+static BOOL UNI_Test(void)
 {
 	char id[6];
 
@@ -125,12 +125,12 @@ BOOL UNI_Test(void)
 	return 0;
 }
 
-BOOL UNI_Init(void)
+static BOOL UNI_Init(void)
 {
 	return 1;
 }
 
-void UNI_Cleanup(void)
+static void UNI_Cleanup(void)
 {
 	_mm_free(wh);
 	s=NULL;
@@ -221,65 +221,65 @@ static UBYTE* readtrack(void)
 static BOOL loadsmp6(void)
 {
 	int t;
-	SAMPLE *s;
+	SAMPLE *sptr;
 
-	s=of.samples;
-	for(t=0;t<of.numsmp;t++,s++) {
+	sptr=of.samples;
+	for(t=0;t<of.numsmp;t++,sptr++) {
 		int flags;
 
 		flags         = _mm_read_M_UWORD(modreader);
-		s->flags=0;
-		if(flags&0x0004) s->flags|=SF_STEREO;
-		if(flags&0x0002) s->flags|=SF_SIGNED;
-		if(flags&0x0001) s->flags|=SF_16BITS;
+		sptr->flags=0;
+		if(flags&0x0004) sptr->flags|=SF_STEREO;
+		if(flags&0x0002) sptr->flags|=SF_SIGNED;
+		if(flags&0x0001) sptr->flags|=SF_16BITS;
 		/* convert flags */
 		if(universion>=0x104) {
-			if(flags&0x2000) s->flags|=SF_UST_LOOP;
-			if(flags&0x1000) s->flags|=SF_OWNPAN;
-			if(flags&0x0800) s->flags|=SF_SUSTAIN;
-			if(flags&0x0400) s->flags|=SF_REVERSE;
-			if(flags&0x0200) s->flags|=SF_BIDI;
-			if(flags&0x0100) s->flags|=SF_LOOP;
-			if(flags&0x0020) s->flags|=SF_ITPACKED;
-			if(flags&0x0010) s->flags|=SF_DELTA;
-			if(flags&0x0008) s->flags|=SF_BIG_ENDIAN;
+			if(flags&0x2000) sptr->flags|=SF_UST_LOOP;
+			if(flags&0x1000) sptr->flags|=SF_OWNPAN;
+			if(flags&0x0800) sptr->flags|=SF_SUSTAIN;
+			if(flags&0x0400) sptr->flags|=SF_REVERSE;
+			if(flags&0x0200) sptr->flags|=SF_BIDI;
+			if(flags&0x0100) sptr->flags|=SF_LOOP;
+			if(flags&0x0020) sptr->flags|=SF_ITPACKED;
+			if(flags&0x0010) sptr->flags|=SF_DELTA;
+			if(flags&0x0008) sptr->flags|=SF_BIG_ENDIAN;
 		} else if(universion>=0x102) {
-			if(flags&0x0800) s->flags|=SF_UST_LOOP;
-			if(flags&0x0400) s->flags|=SF_OWNPAN;
-			if(flags&0x0200) s->flags|=SF_SUSTAIN;
-			if(flags&0x0100) s->flags|=SF_REVERSE;
-			if(flags&0x0080) s->flags|=SF_BIDI;
-			if(flags&0x0040) s->flags|=SF_LOOP;
-			if(flags&0x0020) s->flags|=SF_ITPACKED;
-			if(flags&0x0010) s->flags|=SF_DELTA;
-			if(flags&0x0008) s->flags|=SF_BIG_ENDIAN;
+			if(flags&0x0800) sptr->flags|=SF_UST_LOOP;
+			if(flags&0x0400) sptr->flags|=SF_OWNPAN;
+			if(flags&0x0200) sptr->flags|=SF_SUSTAIN;
+			if(flags&0x0100) sptr->flags|=SF_REVERSE;
+			if(flags&0x0080) sptr->flags|=SF_BIDI;
+			if(flags&0x0040) sptr->flags|=SF_LOOP;
+			if(flags&0x0020) sptr->flags|=SF_ITPACKED;
+			if(flags&0x0010) sptr->flags|=SF_DELTA;
+			if(flags&0x0008) sptr->flags|=SF_BIG_ENDIAN;
 		} else {
-			if(flags&0x400) s->flags|=SF_UST_LOOP;
-			if(flags&0x200) s->flags|=SF_OWNPAN;
-			if(flags&0x100) s->flags|=SF_REVERSE;
-			if(flags&0x080) s->flags|=SF_SUSTAIN;
-			if(flags&0x040) s->flags|=SF_BIDI;
-			if(flags&0x020) s->flags|=SF_LOOP;
-			if(flags&0x010) s->flags|=SF_BIG_ENDIAN;
-			if(flags&0x008) s->flags|=SF_DELTA;
+			if(flags&0x400) sptr->flags|=SF_UST_LOOP;
+			if(flags&0x200) sptr->flags|=SF_OWNPAN;
+			if(flags&0x100) sptr->flags|=SF_REVERSE;
+			if(flags&0x080) sptr->flags|=SF_SUSTAIN;
+			if(flags&0x040) sptr->flags|=SF_BIDI;
+			if(flags&0x020) sptr->flags|=SF_LOOP;
+			if(flags&0x010) sptr->flags|=SF_BIG_ENDIAN;
+			if(flags&0x008) sptr->flags|=SF_DELTA;
 		}
 
-		s->speed      = _mm_read_M_ULONG(modreader);
-		s->volume     = _mm_read_UBYTE(modreader);
-		s->panning    = _mm_read_M_UWORD(modreader);
-		s->length     = _mm_read_M_ULONG(modreader);
-		s->loopstart  = _mm_read_M_ULONG(modreader);
-		s->loopend    = _mm_read_M_ULONG(modreader);
-		s->susbegin   = _mm_read_M_ULONG(modreader);
-		s->susend     = _mm_read_M_ULONG(modreader);
-		s->globvol    = _mm_read_UBYTE(modreader);
-		s->vibflags   = _mm_read_UBYTE(modreader);
-		s->vibtype    = _mm_read_UBYTE(modreader);
-		s->vibsweep   = _mm_read_UBYTE(modreader);
-		s->vibdepth   = _mm_read_UBYTE(modreader);
-		s->vibrate    = _mm_read_UBYTE(modreader);
+		sptr->speed      = _mm_read_M_ULONG(modreader);
+		sptr->volume     = _mm_read_UBYTE(modreader);
+		sptr->panning    = _mm_read_M_UWORD(modreader);
+		sptr->length     = _mm_read_M_ULONG(modreader);
+		sptr->loopstart  = _mm_read_M_ULONG(modreader);
+		sptr->loopend    = _mm_read_M_ULONG(modreader);
+		sptr->susbegin   = _mm_read_M_ULONG(modreader);
+		sptr->susend     = _mm_read_M_ULONG(modreader);
+		sptr->globvol    = _mm_read_UBYTE(modreader);
+		sptr->vibflags   = _mm_read_UBYTE(modreader);
+		sptr->vibtype    = _mm_read_UBYTE(modreader);
+		sptr->vibsweep   = _mm_read_UBYTE(modreader);
+		sptr->vibdepth   = _mm_read_UBYTE(modreader);
+		sptr->vibrate    = _mm_read_UBYTE(modreader);
 
-		s->samplename=readstring();
+		sptr->samplename=readstring();
 
 		if(_mm_eof(modreader)) {
 			_mm_errno = MMERR_LOADING_SAMPLEINFO;
@@ -498,13 +498,13 @@ static BOOL loadsmp5(void)
 	return 1;
 }
 
-BOOL UNI_Load(BOOL curious)
+static BOOL UNI_Load(BOOL curious)
 {
 	int t;
 	char *modtype,*oldtype=NULL;
 	INSTRUMENT *d;
 	SAMPLE *q;
-	
+
 	/* read module header */
 	_mm_read_UBYTES(mh.id,4,modreader);
 	if(mh.id[3]!='N')
@@ -513,11 +513,11 @@ BOOL UNI_Load(BOOL curious)
 		universion=0x100;
 
 	if(universion>=6) {
-		if (universion==6)
-			_mm_read_UBYTE(modreader);
-		else
+		if (universion==6) {
+			_mm_skip_BYTE(modreader);
+		} else {
 			universion=_mm_read_M_UWORD(modreader);
-
+		}
 		mh.flags     =_mm_read_M_UWORD(modreader);
 		mh.numchn    =_mm_read_UBYTE(modreader);
 		mh.numvoices =_mm_read_UBYTE(modreader);
@@ -555,7 +555,7 @@ BOOL UNI_Load(BOOL curious)
 		mh.flags &= UF_XMPERIODS | UF_LINEAR;
 		mh.flags |= UF_INST | UF_NOWRAP | UF_PANNING;
 	}
-	
+
 	/* set module parameters */
 	of.flags     =mh.flags;
 	of.numchn    =mh.numchn;
@@ -576,7 +576,7 @@ BOOL UNI_Load(BOOL curious)
 	if(universion<0x102)
 		oldtype=readstring();
 	if(oldtype) {
-		int len=strlen(oldtype)+20;
+		size_t len=strlen(oldtype)+20;
 		if(!(modtype=_mm_malloc(len))) return 0;
 #ifdef HAVE_SNPRINTF
 		snprintf(modtype,len,"%s (was %s)",(universion>=0x100)?"APlayer":"MikCvt2",oldtype);
@@ -688,7 +688,7 @@ BOOL UNI_Load(BOOL curious)
 	return 1;
 }
 
-CHAR *UNI_LoadTitle(void)
+static CHAR *UNI_LoadTitle(void)
 {
 	UBYTE ver;
 	int posit[3]={304,306,26};
