@@ -1,34 +1,99 @@
-/*	NOTE: this file needs macintosh linefeeds (\r) to work with Rez! */
+/*	libmikmodversion.r
+	NOTE: this file needs macintosh linefeeds (\r) to work with Rez!
+*/
 
 #ifndef __TYPES_R__
 #include "Types.r"
 #endif
 
+#ifndef __BALLOONS_R__
+#include "Balloons.r"
+#endif
+
+#define LIBMIKMOD_VERSION_MAJOR			3
+#define LIBMIKMOD_VERSION_MINOR			1
+#define LIBMIKMOD_REVISION			16
+#define LIBMIKMOD_VERSION_STRING 		"3.1.16"
+#define LIBMIKMOD_STATE				release
+#define LIBMIKMOD_RELEASE_NO			0
+#define LIBMIKMOD_COUNTRY			verSweden
+#define LIBMIKMOD_NAME				"libmikmod"
+#define LIBMIKMOD_SHORT_DESCRIPTION		"music module player"
+#define LIBMIKMOD_LONG_DESCRIPTION		"A portable sound / music module playing shared library."
+
+/*	Resources for libmikmod shared library : */
+
 resource 'vers' (1) {
-	0x3,
-	0x17,
-	release,
-	0x0,
-	verSweden,
-	"3.1.7",
-	"3.1.7"
+	LIBMIKMOD_VERSION_MAJOR,
+	(LIBMIKMOD_VERSION_MINOR << 4) | LIBMIKMOD_REVISION,
+	LIBMIKMOD_STATE,
+	LIBMIKMOD_RELEASE_NO,
+	LIBMIKMOD_COUNTRY,
+	LIBMIKMOD_VERSION_STRING,
+	LIBMIKMOD_VERSION_STRING
 };
 
 resource 'vers' (2) {
-	0x3,
-	0x17,
-	release,
-	0x0,
-	verSweden,
-	"3.1.7",
-	"music module player"
+	LIBMIKMOD_VERSION_MAJOR,
+	(LIBMIKMOD_VERSION_MINOR << 4) | LIBMIKMOD_REVISION,
+	LIBMIKMOD_STATE,
+	LIBMIKMOD_RELEASE_NO,
+	LIBMIKMOD_COUNTRY,
+	LIBMIKMOD_VERSION_STRING,
+	LIBMIKMOD_SHORT_DESCRIPTION
 };
 
 
-/*	nice custom icon for extension, drawn by Anders F Bjrklund, follows:
-	NOTE: must set file's "use custom icon" bit, to actually show it */
+	/* Extension Manager info */
+data 'CCI' (128) {		
+	LIBMIKMOD_NAME "\n\n"
+		LIBMIKMOD_LONG_DESCRIPTION
+};
 
-resource 'ICN#' (kCustomIconResource) {
+	/* Finder help balloon */
+resource 'hfdr' (kHMHelpID) {
+	HelpMgrVersion,
+	hmDefaultOptions,
+	0,
+	0,
+	{	
+		HMStringItem
+		{
+			LIBMIKMOD_NAME "\n\n"
+				LIBMIKMOD_LONG_DESCRIPTION
+		}
+	}
+	
+};
+
+resource 'BNDL' (128) {
+	'lmm!',
+	0,
+	{	'ICN#',
+		{	0, 128
+		},
+		'FREF',
+		{	0, 128
+		}
+	}
+};
+
+resource 'FREF' (128) {
+	'shlb',
+	0,
+	""
+};
+
+	/* Owner resource */
+data 'lmm!' (0) {
+	$"00"                                                 
+};
+
+
+
+/*	nice custom icon for extension, drawn by Anders F Bjrklund, follows: */
+
+resource 'ICN#' (128) {
 	{	/* array: 2 elements */
 		/* [1] */
 		$"7FFF FFF0 8000 0008 8000 0008 8015 0008"
@@ -51,7 +116,7 @@ resource 'ICN#' (kCustomIconResource) {
 	}
 };
 
-resource 'icl8' (kCustomIconResource) {
+resource 'icl8' (128) {
 	$"00FF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"
 	$"FFFF FFFF FFFF FFFF FFFF FFFF 0000 0000"
 	$"FF00 0000 0000 0000 0000 0000 0000 0000"
@@ -119,7 +184,7 @@ resource 'icl8' (kCustomIconResource) {
 };
 
 
-resource 'ics#' (kCustomIconResource) {
+resource 'ics#' (128) {
 	{	/* array: 2 elements */
 		/* [1] */
 		$"FFFE 8002 8002 8102 8102 C103 4001 4281"
@@ -130,7 +195,7 @@ resource 'ics#' (kCustomIconResource) {
 	}
 };
 
-resource 'ics8' (kCustomIconResource) {
+resource 'ics8' (128) {
 	$"FBFF FFFF FFFF FFFF FFFF FFFF FFFF FB00"
 	$"FF00 0000 0000 0000 0000 0000 00F6 FF00"
 	$"FFF6 F6F6 F6F6 F6F6 F6F6 F6F6 F6F8 FF00"
