@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -45,8 +45,8 @@
 extern int fprintf(FILE *, const char *, ...);
 #endif
 
-		MREADER *modreader;
-		MODULE of;
+MREADER *modreader;
+MODULE of;
 
 static	MLOADER *firstloader=NULL;
 
@@ -63,15 +63,18 @@ MIKMODAPI CHAR* MikMod_InfoLoader(void)
 
 	MUTEX_LOCK(lists);
 	/* compute size of buffer */
-	for(l=firstloader;l;l=l->next) len+=1+(l->next?1:0)+strlen(l->version);
+	for(l = firstloader; l; l = l->next)
+		len += 1 + (l->next ? 1 : 0) + strlen(l->version);
 
 	if(len)
-		if((list=_mm_malloc(len*sizeof(CHAR)))) {
-			list[0]=0;
-			/* list all registered module loders */
-			for(l=firstloader;l;l=l->next)
-				sprintf(list,(l->next)?"%s%s\n":"%s%s",list,l->version);
+	  if((list=_mm_malloc(len*sizeof(CHAR)))) {
+		CHAR *list_end = list;
+		list[0] = 0;
+		/* list all registered module loders */
+		for(l = firstloader; l; l = l->next) {
+		    list_end += sprintf(list_end, "%s%s", l->version, (l->next) ? "\n" : "");
 		}
+	}
 	MUTEX_UNLOCK(lists);
 	return list;
 }
@@ -84,7 +87,7 @@ void _mm_registerloader(MLOADER* ldr)
 		while(cruise->next) cruise = cruise->next;
 		cruise->next=ldr;
 	} else
-		firstloader=ldr; 
+		firstloader=ldr;
 }
 
 MIKMODAPI void MikMod_RegisterLoader(struct MLOADER* ldr)
@@ -106,7 +109,7 @@ BOOL ReadComment(UWORD len)
 
 		if(!(of.comment=(CHAR*)_mm_malloc(len+1))) return 0;
 		_mm_read_UBYTES(of.comment,len,modreader);
-		
+
 		/* translate IT linefeeds */
 		for(i=0;i<len;i++)
 			if(of.comment[i]=='\r') of.comment[i]='\n';
@@ -207,7 +210,7 @@ BOOL AllocTracks(void)
 BOOL AllocInstruments(void)
 {
 	int t,n;
-	
+
 	if(!of.numins) {
 		_mm_errno=MMERR_NOT_A_MODULE;
 		return 0;
@@ -216,11 +219,11 @@ BOOL AllocInstruments(void)
 		return 0;
 
 	for(t=0;t<of.numins;t++) {
-		for(n=0;n<INSTNOTES;n++) { 
+		for(n=0;n<INSTNOTES;n++) {
 			/* Init note / sample lookup table */
 			of.instruments[t].samplenote[n]   = n;
 			of.instruments[t].samplenumber[n] = t;
-		}   
+		}
 		of.instruments[t].globvol = 64;
 	}
 	return 1;
@@ -257,7 +260,7 @@ static BOOL ML_LoadSamples(void)
 }
 
 /* Creates a CSTR out of a character buffer of 'len' bytes, but strips any
-   terminating non-printing characters like 0, spaces etc.                    */
+   terminating non-printing characters like 0, spaces etc. */
 CHAR *DupStr(CHAR* s,UWORD len,BOOL strict)
 {
 	UWORD t;
@@ -288,7 +291,9 @@ static void ML_XFreeSample(SAMPLE *s)
 {
 	if(s->handle>=0)
 		MD_SampleUnload(s->handle);
-	if(s->samplename) free(s->samplename);
+
+/* moved samplename freeing to our caller ML_FreeEx(),
+ * because we are called conditionally. */
 }
 
 static void ML_XFreeInstrument(INSTRUMENT *i)
@@ -319,8 +324,10 @@ static void ML_FreeEx(MODULE *mf)
 		free(mf->instruments);
 	}
 	if(mf->samples) {
-		for(t=0;t<mf->numsmp;t++)
+		for(t=0;t<mf->numsmp;t++) {
+			if(mf->samples[t].samplename) free(mf->samples[t].samplename);
 			if(mf->samples[t].length) ML_XFreeSample(&mf->samples[t]);
+		}
 		free(mf->samples);
 	}
 	memset(mf,0,sizeof(MODULE));
@@ -406,7 +413,7 @@ MIKMODAPI CHAR* Player_LoadTitle(CHAR* filename)
 }
 
 /* Loads a module given an reader */
-MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curious)
+static MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curious)
 {
 	int t;
 	MLOADER *l;
@@ -427,14 +434,16 @@ MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curious)
 	if(!l) {
 		_mm_errno = MMERR_NOT_A_MODULE;
 		if(_mm_errorhandler) _mm_errorhandler();
-		_mm_rewind(modreader);_mm_iobase_revert();
+		_mm_rewind(modreader);
+		_mm_iobase_revert();
 		return NULL;
 	}
 
 	/* init unitrk routines */
 	if(!UniInit()) {
 		if(_mm_errorhandler) _mm_errorhandler();
-		_mm_rewind(modreader);_mm_iobase_revert();
+		_mm_rewind(modreader);
+		_mm_iobase_revert();
 		return NULL;
 	}
 
@@ -450,10 +459,12 @@ MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curious)
 	if (!l->Init || l->Init()) {
 		_mm_rewind(modreader);
 		ok = l->Load(curious);
-		/* propagate inflags=flags for in-module samples */
-		for (t = 0; t < of.numsmp; t++)
-			if (of.samples[t].inflags == 0)
-				of.samples[t].inflags = of.samples[t].flags;
+		if (ok) {
+			/* propagate inflags=flags for in-module samples */
+			for (t = 0; t < of.numsmp; t++)
+				if (of.samples[t].inflags == 0)
+					of.samples[t].inflags = of.samples[t].flags;
+		}
 	} else
 		ok = 0;
 
@@ -464,14 +475,16 @@ MODULE* Player_LoadGeneric_internal(MREADER *reader,int maxchan,BOOL curious)
 	if(!ok) {
 		ML_FreeEx(&of);
 		if(_mm_errorhandler) _mm_errorhandler();
-		_mm_rewind(modreader);_mm_iobase_revert();
+		_mm_rewind(modreader);
+		_mm_iobase_revert();
 		return NULL;
 	}
 
 	if(!ML_LoadSamples()) {
 		ML_FreeEx(&of);
 		if(_mm_errorhandler) _mm_errorhandler();
-		_mm_rewind(modreader);_mm_iobase_revert();
+		_mm_rewind(modreader);
+		_mm_iobase_revert();
 		return NULL;
 	}
 
