@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: mwav.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: mwav.c,v 1.1.1.1 2004/06/01 12:16:18 raph Exp $
 
   WAV sample loader
 
@@ -60,7 +60,7 @@ typedef struct WAV {
 	UWORD nFormatSpecific;
 } WAV;
 
-SAMPLE* Sample_LoadGeneric_internal(MREADER* reader)
+static SAMPLE* Sample_LoadGeneric_internal(MREADER* reader)
 {
 	SAMPLE *si=NULL;
 	WAV wh;
@@ -103,7 +103,7 @@ SAMPLE* Sample_LoadGeneric_internal(MREADER* reader)
 
 #ifdef MIKMOD_DEBUG
 			fprintf(stderr,"\rwavloader : wFormatTag=%04x blockalign=%04x nFormatSpc=%04x\n",
-			        wh.wFormatTag,wh.nBlockAlign,wh.nFormatSpecific);
+				wh.wFormatTag,wh.nBlockAlign,wh.nFormatSpecific);
 #endif
 
 			if((have_fmt)||(wh.nChannels>1)) {
@@ -130,7 +130,7 @@ SAMPLE* Sample_LoadGeneric_internal(MREADER* reader)
 			si->inflags = si->flags;
 			SL_RegisterSample(si,MD_SNDFX,reader);
 			SL_LoadSamples();
-			
+
 			/* skip any other remaining blocks - so in case of repeated sample
 			   fragments, we'll return the first anyway instead of an error */
 			break;
