@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: virtch.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: virtch.c,v 1.1.1.1 2004/06/01 12:16:18 raph Exp $
 
   Sample mixing routines, using a 32 bits mixing buffer.
 
@@ -50,7 +50,7 @@
    Constant definitions
    ====================
 
-  	BITSHIFT
+	BITSHIFT
 		Controls the maximum volume of the sound output.  All data is shifted
 		right by BITSHIFT after being mixed. Higher values result in quieter
 		sound and less chance of distortion.
@@ -130,37 +130,37 @@ static	SLONG *RVbufR1=NULL,*RVbufR2=NULL,*RVbufR3=NULL,*RVbufR4=NULL,
 /*========== 32 bit sample mixers - only for 32 bit platforms */
 #ifndef NATIVE_64BIT_INT
 
-static SLONG Mix32MonoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32MonoNormal(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
 
 	while(todo--) {
-		sample = srce[index >> FRACBITS];
-		index += increment;
+		sample = srce[idx >> FRACBITS];
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONG Mix32StereoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32StereoNormal(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
 	SLONG rvolsel = vnf->rvolsel;
 
 	while(todo--) {
-		sample=srce[index >> FRACBITS];
-		index += increment;
+		sample=srce[idx >> FRACBITS];
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 		*dest++ += rvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONG Mix32SurroundNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32SurroundNormal(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -168,25 +168,26 @@ static SLONG Mix32SurroundNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG incre
 
 	if (lvolsel>=rvolsel) {
 		while(todo--) {
-			sample = srce[index >> FRACBITS];
-			index += increment;
+			sample = srce[idx >> FRACBITS];
+			idx += increment;
 
 			*dest++ += lvolsel*sample;
 			*dest++ -= lvolsel*sample;
 		}
-	} else {
+	}
+	else {
 		while(todo--) {
-			sample = srce[index >> FRACBITS];
-			index += increment;
+			sample = srce[idx >> FRACBITS];
+			idx += increment;
 
 			*dest++ -= rvolsel*sample;
 			*dest++ += rvolsel*sample;
 		}
 	}
-	return index;
+	return idx;
 }
 
-static SLONG Mix32MonoInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32MonoInterp(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -195,33 +196,33 @@ static SLONG Mix32MonoInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increment
 	if (rampvol) {
 		SLONG oldlvol = vnf->oldlvol - lvolsel;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			*dest++ += ((lvolsel << CLICK_SHIFT) + oldlvol * rampvol)
-			           * sample >> CLICK_SHIFT;
+					   * sample >> CLICK_SHIFT;
 			if (!--rampvol)
 				break;
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONG Mix32StereoInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32StereoInterp(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -232,13 +233,13 @@ static SLONG Mix32StereoInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increme
 		SLONG oldlvol = vnf->oldlvol - lvolsel;
 		SLONG oldrvol = vnf->oldrvol - rvolsel;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			*dest++ += ((lvolsel << CLICK_SHIFT) + oldlvol * rampvol)
-			           * sample >> CLICK_SHIFT;
+					   * sample >> CLICK_SHIFT;
 			*dest++ += ((rvolsel << CLICK_SHIFT) + oldrvol * rampvol)
 					   * sample >> CLICK_SHIFT;
 			if (!--rampvol)
@@ -246,22 +247,22 @@ static SLONG Mix32StereoInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increme
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 		*dest++ += rvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONG Mix32SurroundInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32SurroundInterp(const SWORD* srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -280,13 +281,13 @@ static SLONG Mix32SurroundInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG incre
 	if (rampvol) {
 		oldvol -= vol;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			sample=((vol << CLICK_SHIFT) + oldvol * rampvol)
-				   * sample >> CLICK_SHIFT;
+					   * sample >> CLICK_SHIFT;
 			*dest++ += sample;
 			*dest++ -= sample;
 
@@ -295,55 +296,55 @@ static SLONG Mix32SurroundInterp(SWORD* srce,SLONG* dest,SLONG index,SLONG incre
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += vol*sample;
 		*dest++ -= vol*sample;
 	}
-	return index;
+	return idx;
 }
 #endif
 
 /*========== 64 bit sample mixers - all platforms */
 
-static SLONGLONG MixMonoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixMonoNormal(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
 
 	while(todo--) {
-		sample = srce[index >> FRACBITS];
-		index += increment;
+		sample = srce[idx >> FRACBITS];
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixStereoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixStereoNormal(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
 	SLONG rvolsel = vnf->rvolsel;
 
 	while(todo--) {
-		sample=srce[index >> FRACBITS];
-		index += increment;
+		sample=srce[idx >> FRACBITS];
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 		*dest++ += rvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixSurroundNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixSurroundNormal(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SWORD sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -351,25 +352,26 @@ static SLONGLONG MixSurroundNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONG
 
 	if(vnf->lvolsel>=vnf->rvolsel) {
 		while(todo--) {
-			sample = srce[index >> FRACBITS];
-			index += increment;
+			sample = srce[idx >> FRACBITS];
+			idx += increment;
 
 			*dest++ += lvolsel*sample;
 			*dest++ -= lvolsel*sample;
 		}
-	} else {
+	}
+	else {
 		while(todo--) {
-			sample = srce[index >> FRACBITS];
-			index += increment;
+			sample = srce[idx >> FRACBITS];
+			idx += increment;
 
 			*dest++ -= rvolsel*sample;
 			*dest++ += rvolsel*sample;
 		}
 	}
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixMonoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixMonoInterp(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -378,10 +380,10 @@ static SLONGLONG MixMonoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG
 	if (rampvol) {
 		SLONG oldlvol = vnf->oldlvol - lvolsel;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			*dest++ += ((lvolsel << CLICK_SHIFT) + oldlvol * rampvol)
 					   * sample >> CLICK_SHIFT;
@@ -390,21 +392,21 @@ static SLONGLONG MixMonoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixStereoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixStereoInterp(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -415,10 +417,10 @@ static SLONGLONG MixStereoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLO
 		SLONG oldlvol = vnf->oldlvol - lvolsel;
 		SLONG oldrvol = vnf->oldrvol - rvolsel;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			*dest++ +=((lvolsel << CLICK_SHIFT) + oldlvol * rampvol)
 					   * sample >> CLICK_SHIFT;
@@ -429,22 +431,22 @@ static SLONGLONG MixStereoInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLO
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += lvolsel * sample;
 		*dest++ += rvolsel * sample;
 	}
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixSurroundInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixSurroundInterp(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SLONG sample;
 	SLONG lvolsel = vnf->lvolsel;
@@ -463,13 +465,13 @@ static SLONGLONG MixSurroundInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONG
 	if (rampvol) {
 		oldvol -= vol;
 		while(todo--) {
-			sample=(SLONG)srce[index>>FRACBITS]+
-			       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-			        *(index&FRACMASK)>>FRACBITS);
-			index += increment;
+			sample=(SLONG)srce[idx>>FRACBITS]+
+				((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+				 *(idx&FRACMASK)>>FRACBITS);
+			idx += increment;
 
 			sample=((vol << CLICK_SHIFT) + oldvol * rampvol)
-				   * sample >> CLICK_SHIFT;
+					   * sample >> CLICK_SHIFT;
 			*dest++ += sample;
 			*dest++ -= sample;
 			if (!--rampvol)
@@ -477,19 +479,19 @@ static SLONGLONG MixSurroundInterp(SWORD* srce,SLONG* dest,SLONGLONG index,SLONG
 		}
 		vnf->rampvol = rampvol;
 		if (todo < 0)
-			return index;
+			return idx;
 	}
 
 	while(todo--) {
-		sample=(SLONG)srce[index>>FRACBITS]+
-		       ((SLONG)(srce[(index>>FRACBITS)+1]-srce[index>>FRACBITS])
-		        *(index&FRACMASK)>>FRACBITS);
-		index += increment;
+		sample=(SLONG)srce[idx>>FRACBITS]+
+			((SLONG)(srce[(idx>>FRACBITS)+1]-srce[idx>>FRACBITS])
+			 *(idx&FRACMASK)>>FRACBITS);
+		idx += increment;
 
 		*dest++ += vol*sample;
 		*dest++ -= vol*sample;
 	}
-	return index;
+	return idx;
 }
 
 static void (*MixReverb)(SLONG* srce,NATIVE count);
@@ -526,7 +528,7 @@ static void MixReverb_Normal(SLONG* srce,NATIVE count)
 
 		/* left channel */
 		*srce++ +=RVbufL1[loc1]-RVbufL2[loc2]+RVbufL3[loc3]-RVbufL4[loc4]+
-		          RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
+			  RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
 	}
 }
 
@@ -563,10 +565,10 @@ static void MixReverb_Stereo(SLONG* srce,NATIVE count)
 
 		/* left channel then right channel */
 		*srce++ +=RVbufL1[loc1]-RVbufL2[loc2]+RVbufL3[loc3]-RVbufL4[loc4]+
-		          RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
+			  RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
 
 		*srce++ +=RVbufR1[loc1]-RVbufR2[loc2]+RVbufR3[loc3]-RVbufR4[loc4]+
-		          RVbufR5[loc5]-RVbufR6[loc6]+RVbufR7[loc7]-RVbufR8[loc8];
+			  RVbufR5[loc5]-RVbufR6[loc6]+RVbufR7[loc7]-RVbufR8[loc8];
 	}
 }
 
@@ -575,7 +577,7 @@ static void MixReverb_Stereo(SLONG* srce,NATIVE count)
 #define CHECK_SAMPLE(var,bound) var=(var>=bound)?bound-1:(var<-bound)?-bound:var
 #define PUT_SAMPLE(var) *dste++=var
 
-static void Mix32To16(SWORD* dste,SLONG* srce,NATIVE count)
+static void Mix32To16(SWORD* dste,const SLONG *srce,NATIVE count)
 {
 	SLONG x1,x2,x3,x4;
 	int	remain;
@@ -597,7 +599,7 @@ static void Mix32To16(SWORD* dste,SLONG* srce,NATIVE count)
 	}
 }
 
-static void Mix32To8(SBYTE* dste,SLONG* srce,NATIVE count)
+static void Mix32To8(SBYTE* dste,const SLONG *srce,NATIVE count)
 {
 	SWORD x1,x2,x3,x4;
 	int	remain;
@@ -709,47 +711,48 @@ static void AddChannel(SLONG* ptr,NATIVE todo)
 					if(vc_mode & DMODE_STEREO) {
 						if((vnf->pan==PAN_SURROUND)&&(md_mode&DMODE_SURROUND))
 							vnf->current=Mix32SurroundInterp
-							           (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 						else
 							vnf->current=Mix32StereoInterp
-							           (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 					} else
 						vnf->current=Mix32MonoInterp
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 				} else if(vc_mode & DMODE_STEREO) {
 					if((vnf->pan==PAN_SURROUND)&&(md_mode&DMODE_SURROUND))
 						vnf->current=Mix32SurroundNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 					else
 						vnf->current=Mix32StereoNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 				} else
 					vnf->current=Mix32MonoNormal
-					                   (s,ptr,vnf->current,vnf->increment,done);
-			} else
+								   (s,ptr,vnf->current,vnf->increment,done);
+			}
+			else
 #endif
-			       {
+			{
 				if((md_mode & DMODE_INTERP)) {
 					if(vc_mode & DMODE_STEREO) {
 						if((vnf->pan==PAN_SURROUND)&&(md_mode&DMODE_SURROUND))
 							vnf->current=MixSurroundInterp
-							           (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 						else
 							vnf->current=MixStereoInterp
-							           (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 					} else
 						vnf->current=MixMonoInterp
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 				} else if(vc_mode & DMODE_STEREO) {
 					if((vnf->pan==PAN_SURROUND)&&(md_mode&DMODE_SURROUND))
 						vnf->current=MixSurroundNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 					else
 						vnf->current=MixStereoNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 				} else
 					vnf->current=MixMonoNormal
-					                   (s,ptr,vnf->current,vnf->increment,done);
+								   (s,ptr,vnf->current,vnf->increment,done);
 			}
 		} else
 			/* update sample position */
@@ -834,10 +837,10 @@ void VC1_WriteSamples(SBYTE* buf,ULONG todo)
 	}
 }
 
-BOOL VC1_Init(void)
+int VC1_Init(void)
 {
 	VC_SetupPointers();
-	
+
 	if (md_mode&DMODE_HQMIXER)
 		return VC2_Init();
 
@@ -845,18 +848,19 @@ BOOL VC1_Init(void)
 		_mm_errno = MMERR_INITIALIZING_MIXER;
 		return 1;
 	}
-	if(!vc_tickbuf)
+	if(!vc_tickbuf) {
 		if(!(vc_tickbuf=(SLONG*)_mm_malloc((TICKLSIZE+32)*sizeof(SLONG)))) {
 			_mm_errno = MMERR_INITIALIZING_MIXER;
 			return 1;
 		}
+	}
 
 	MixReverb=(md_mode&DMODE_STEREO)?MixReverb_Stereo:MixReverb_Normal;
 	vc_mode = md_mode;
 	return 0;
 }
 
-BOOL VC1_PlayStart(void)
+int VC1_PlayStart(void)
 {
 	samplesthatfit=TICKLSIZE;
 	if(vc_mode & DMODE_STEREO) samplesthatfit >>= 1;
@@ -915,14 +919,14 @@ void VC1_PlayStop(void)
 	RVbufR1=RVbufR2=RVbufR3=RVbufR4=RVbufR5=RVbufR6=RVbufR7=RVbufR8=NULL;
 }
 
-BOOL VC1_SetNumVoices(void)
+int VC1_SetNumVoices(void)
 {
 	int t;
 
 	if(!(vc_softchn=md_softchn)) return 0;
 
 	if(vinf) free(vinf);
-	if(!(vinf= _mm_calloc(sizeof(VINFO),vc_softchn))) return 1;
+	if(!(vinf= _mm_calloc(vc_softchn,sizeof(VINFO)))) return 1;
 
 	for(t=0;t<vc_softchn;t++) {
 		vinf[t].frq=10000;
