@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: virtch2.c,v 1.1.1.1 2004/01/21 01:36:35 raph Exp $
+  $Id: virtch2.c,v 1.1.1.1 2004/06/01 12:16:18 raph Exp $
 
   High-quality sample mixing routines, using a 32 bits mixing buffer,
   interpolation, and sample smoothing to improve sound quality and remove
@@ -45,7 +45,7 @@
 #include <string.h>
 
 #include "mikmod_internals.h"
-  
+
 /*
    Constant Definitions
    ====================
@@ -150,16 +150,16 @@ static	SLONG *RVbufR1=NULL,*RVbufR2=NULL,*RVbufR3=NULL,*RVbufR4=NULL,
 /*========== 32 bit sample mixers - only for 32 bit platforms */
 #ifndef NATIVE_64BIT_INT
 
-static SLONG Mix32MonoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,SLONG todo)
+static SLONG Mix32MonoNormal(const SWORD* const srce,SLONG* dest,SLONG idx,SLONG increment,SLONG todo)
 {
 	SWORD sample=0;
 	SLONG i,f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=(((SLONG)(srce[i]*(FRACMASK+1L-f)) +
 		        ((SLONG)srce[i+1]*f)) >> FRACBITS);
-		index+=increment;
+		idx+=increment;
 
 		if(vnf->rampvol) {
 			*dest++ += (long)(
@@ -179,19 +179,19 @@ static SLONG Mix32MonoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment
 	}
 	vnf->lastvalL=vnf->lvolsel * sample;
 
-	return index;
+	return idx;
 }
 
-static SLONG Mix32StereoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,ULONG todo)
+static SLONG Mix32StereoNormal(const SWORD* const srce,SLONG* dest,SLONG idx,SLONG increment,ULONG todo)
 {
 	SWORD sample=0;
 	SLONG i,f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=((((SLONG)srce[i]*(FRACMASK+1L-f)) +
 		        ((SLONG)srce[i+1] * f)) >> FRACBITS);
-		index += increment;
+		idx += increment;
 
 		if(vnf->rampvol) {
 			*dest++ += (long)(
@@ -222,20 +222,20 @@ static SLONG Mix32StereoNormal(SWORD* srce,SLONG* dest,SLONG index,SLONG increme
 	vnf->lastvalL=vnf->lvolsel*sample;
 	vnf->lastvalR=vnf->rvolsel*sample;
 
-	return index;
+	return idx;
 }
 
-static SLONG Mix32StereoSurround(SWORD* srce,SLONG* dest,SLONG index,SLONG increment,ULONG todo)
+static SLONG Mix32StereoSurround(const SWORD* const srce,SLONG* dest,SLONG idx,SLONG increment,ULONG todo)
 {
 	SWORD sample=0;
 	long whoop;
 	SLONG i, f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=((((SLONG)srce[i]*(FRACMASK+1L-f)) +
 		        ((SLONG)srce[i+1]*f)) >> FRACBITS);
-		index+=increment;
+		idx+=increment;
 
 		if(vnf->rampvol) {
 			whoop=(long)(
@@ -262,22 +262,22 @@ static SLONG Mix32StereoSurround(SWORD* srce,SLONG* dest,SLONG index,SLONG incre
 	vnf->lastvalL=vnf->lvolsel*sample;
 	vnf->lastvalR=vnf->lvolsel*sample;
 
-	return index;
+	return idx;
 }
 #endif
 
 /*========== 64 bit mixers */
 
-static SLONGLONG MixMonoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,SLONG todo)
+static SLONGLONG MixMonoNormal(const SWORD* const srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,SLONG todo)
 {
 	SWORD sample=0;
 	SLONGLONG i,f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=(((SLONGLONG)(srce[i]*(FRACMASK+1L-f)) +
-		        ((SLONGLONG)srce[i+1]*f)) >> FRACBITS);
-		index+=increment;
+			((SLONGLONG)srce[i+1]*f)) >> FRACBITS);
+		idx+=increment;
 
 		if(vnf->rampvol) {
 			*dest++ += (long)(
@@ -297,19 +297,19 @@ static SLONGLONG MixMonoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG
 	}
 	vnf->lastvalL=vnf->lvolsel * sample;
 
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixStereoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,ULONG todo)
+static SLONGLONG MixStereoNormal(const SWORD* const srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,ULONG todo)
 {
 	SWORD sample=0;
 	SLONGLONG i,f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=((((SLONGLONG)srce[i]*(FRACMASK+1L-f)) +
 		        ((SLONGLONG)srce[i+1] * f)) >> FRACBITS);
-		index += increment;
+		idx += increment;
 
 		if(vnf->rampvol) {
 			*dest++ += (long)(
@@ -340,20 +340,20 @@ static SLONGLONG MixStereoNormal(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLO
 	vnf->lastvalL=vnf->lvolsel*sample;
 	vnf->lastvalR=vnf->rvolsel*sample;
 
-	return index;
+	return idx;
 }
 
-static SLONGLONG MixStereoSurround(SWORD* srce,SLONG* dest,SLONGLONG index,SLONGLONG increment,ULONG todo)
+static SLONGLONG MixStereoSurround(const SWORD* srce,SLONG* dest,SLONGLONG idx,SLONGLONG increment,ULONG todo)
 {
 	SWORD sample=0;
 	long whoop;
 	SLONGLONG i, f;
 
 	while(todo--) {
-		i=index>>FRACBITS,f=index&FRACMASK;
+		i=idx>>FRACBITS,f=idx&FRACMASK;
 		sample=((((SLONGLONG)srce[i]*(FRACMASK+1L-f)) +
-		        ((SLONGLONG)srce[i+1]*f)) >> FRACBITS);
-		index+=increment;
+			((SLONGLONG)srce[i+1]*f)) >> FRACBITS);
+		idx+=increment;
 
 		if(vnf->rampvol) {
 			whoop=(long)(
@@ -380,19 +380,19 @@ static SLONGLONG MixStereoSurround(SWORD* srce,SLONG* dest,SLONGLONG index,SLONG
 	vnf->lastvalL=vnf->lvolsel*sample;
 	vnf->lastvalR=vnf->lvolsel*sample;
 
-	return index;
+	return idx;
 }
 
-static	void(*Mix32to16)(SWORD* dste,SLONG* srce,NATIVE count);
-static	void(*Mix32to8)(SBYTE* dste,SLONG* srce,NATIVE count);
-static	void(*MixReverb)(SLONG* srce,NATIVE count);
+static	void(*Mix32to16)(SWORD* dste,const SLONG *srce,NATIVE count);
+static	void(*Mix32to8)(SBYTE* dste,const SLONG *srce,NATIVE count);
+static	void(*MixReverb)(SLONG *srce,NATIVE count);
 
 /* Reverb macros */
 #define COMPUTE_LOC(n) loc##n = RVRindex % RVc##n
 #define COMPUTE_LECHO(n) RVbufL##n [loc##n ]=speedup+((ReverbPct*RVbufL##n [loc##n ])>>7)
 #define COMPUTE_RECHO(n) RVbufR##n [loc##n ]=speedup+((ReverbPct*RVbufR##n [loc##n ])>>7)
 
-static void MixReverb_Normal(SLONG* srce,NATIVE count)
+static void MixReverb_Normal(SLONG *srce,NATIVE count)
 {
 	NATIVE speedup;
 	int ReverbPct;
@@ -418,7 +418,7 @@ static void MixReverb_Normal(SLONG* srce,NATIVE count)
 
 		/* left channel */
 		*srce++ +=RVbufL1[loc1]-RVbufL2[loc2]+RVbufL3[loc3]-RVbufL4[loc4]+
-		          RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
+			  RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
 	}
 }
 
@@ -453,12 +453,12 @@ static void MixReverb_Stereo(SLONG *srce,NATIVE count)
 		COMPUTE_LOC(5); COMPUTE_LOC(6); COMPUTE_LOC(7); COMPUTE_LOC(8);
 
 		/* left channel */
-		*srce++ +=RVbufL1[loc1]-RVbufL2[loc2]+RVbufL3[loc3]-RVbufL4[loc4]+ 
-		          RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
+		*srce++ +=RVbufL1[loc1]-RVbufL2[loc2]+RVbufL3[loc3]-RVbufL4[loc4]+
+			  RVbufL5[loc5]-RVbufL6[loc6]+RVbufL7[loc7]-RVbufL8[loc8];
 
 		/* right channel */
 		*srce++ +=RVbufR1[loc1]-RVbufR2[loc2]+RVbufR3[loc3]-RVbufR4[loc4]+
-		          RVbufR5[loc5]-RVbufR6[loc6]+RVbufR7[loc7]-RVbufR8[loc8];
+			  RVbufR5[loc5]-RVbufR6[loc6]+RVbufR7[loc7]-RVbufR8[loc8];
 	}
 }
 
@@ -466,7 +466,7 @@ static void MixReverb_Stereo(SLONG *srce,NATIVE count)
 #define EXTRACT_SAMPLE(var,attenuation) var=*srce++/(MAXVOL_FACTOR*attenuation)
 #define CHECK_SAMPLE(var,bound) var=(var>=bound)?bound-1:(var<-bound)?-bound:var
 
-static void Mix32To16_Normal(SWORD* dste,SLONG* srce,NATIVE count)
+static void Mix32To16_Normal(SWORD* dste,const SLONG *srce,NATIVE count)
 {
 	NATIVE x1,x2,tmpx;
 	int i;
@@ -485,7 +485,8 @@ static void Mix32To16_Normal(SWORD* dste,SLONG* srce,NATIVE count)
 	}
 }
 
-static void Mix32To16_Stereo(SWORD* dste,SLONG* srce,NATIVE count)
+
+static void Mix32To16_Stereo(SWORD* dste,const SLONG *srce,NATIVE count)
 {
 	NATIVE x1,x2,x3,x4,tmpx,tmpy;
 	int i;
@@ -508,7 +509,7 @@ static void Mix32To16_Stereo(SWORD* dste,SLONG* srce,NATIVE count)
 	}
 }
 
-static void Mix32To8_Normal(SBYTE* dste,SLONG* srce,NATIVE count)
+static void Mix32To8_Normal(SBYTE* dste,const SLONG *srce,NATIVE count)
 {
 	NATIVE x1,x2,tmpx;
 	int i;
@@ -527,7 +528,7 @@ static void Mix32To8_Normal(SBYTE* dste,SLONG* srce,NATIVE count)
 	}
 }
 
-static void Mix32To8_Stereo(SBYTE* dste,SLONG* srce,NATIVE count)
+static void Mix32To8_Stereo(SBYTE* dste,const SLONG *srce,NATIVE count)
 {
 	NATIVE x1,x2,x3,x4,tmpx,tmpy;
 	int i;
@@ -545,8 +546,8 @@ static void Mix32To8_Stereo(SBYTE* dste,SLONG* srce,NATIVE count)
 			tmpx+=x1+x3;
 			tmpy+=x2+x4;
 		}
-		*dste++ =(tmpx/SAMPLING_FACTOR)+128;        
-		*dste++ =(tmpy/SAMPLING_FACTOR)+128;        
+		*dste++ =(tmpx/SAMPLING_FACTOR)+128;
+		*dste++ =(tmpy/SAMPLING_FACTOR)+128;
 	}
 }
 
@@ -639,26 +640,27 @@ static void AddChannel(SLONG* ptr,NATIVE todo)
 				if(vc_mode & DMODE_STEREO) {
 					if((vnf->pan==PAN_SURROUND)&&(vc_mode&DMODE_SURROUND))
 						vnf->current=Mix32StereoSurround
-						               (s,ptr,vnf->current,vnf->increment,done);
+								(s,ptr,vnf->current,vnf->increment,done);
 					else
 						vnf->current=Mix32StereoNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								(s,ptr,vnf->current,vnf->increment,done);
 				} else
 					vnf->current=Mix32MonoNormal
-					                   (s,ptr,vnf->current,vnf->increment,done);
-			} else
+								(s,ptr,vnf->current,vnf->increment,done);
+			}
+			else
 #endif
-			       {
+			{
 				if(vc_mode & DMODE_STEREO) {
 					if((vnf->pan==PAN_SURROUND)&&(vc_mode&DMODE_SURROUND))
 						vnf->current=MixStereoSurround
-						               (s,ptr,vnf->current,vnf->increment,done);
+								(s,ptr,vnf->current,vnf->increment,done);
 					else
 						vnf->current=MixStereoNormal
-						               (s,ptr,vnf->current,vnf->increment,done);
+								(s,ptr,vnf->current,vnf->increment,done);
 				} else
 					vnf->current=MixMonoNormal
-					                   (s,ptr,vnf->current,vnf->increment,done);
+								(s,ptr,vnf->current,vnf->increment,done);
 			}
 		} else  {
 			vnf->lastvalL = vnf->lastvalR = 0;
@@ -667,7 +669,7 @@ static void AddChannel(SLONG* ptr,NATIVE todo)
 		}
 
 		todo -= done;
-		ptr +=(vc_mode & DMODE_STEREO)?(done<<1):done;
+		ptr += (vc_mode & DMODE_STEREO)?(done<<1):done;
 	}
 }
 
@@ -772,22 +774,23 @@ void VC2_WriteSamples(SBYTE* buf,ULONG todo)
 	}
 }
 
-BOOL VC2_Init(void)
+int VC2_Init(void)
 {
 	VC_SetupPointers();
-	
+
 	if (!(md_mode&DMODE_HQMIXER))
 		return VC1_Init();
-	
+
 	if(!(Samples=(SWORD**)_mm_calloc(MAXSAMPLEHANDLES,sizeof(SWORD*)))) {
 		_mm_errno = MMERR_INITIALIZING_MIXER;
 		return 1;
 	}
-	if(!vc_tickbuf)
+	if(!vc_tickbuf) {
 		if(!(vc_tickbuf=(SLONG*)_mm_malloc((TICKLSIZE+32)*sizeof(SLONG)))) {
 			_mm_errno = MMERR_INITIALIZING_MIXER;
 			return 1;
 		}
+	}
 
 	if(md_mode & DMODE_STEREO) {
 		Mix32to16  = Mix32To16_Stereo;
@@ -803,7 +806,7 @@ BOOL VC2_Init(void)
 	return 0;
 }
 
-BOOL VC2_PlayStart(void)
+int VC2_PlayStart(void)
 {
 	md_mode|=DMODE_INTERP;
 
@@ -865,7 +868,7 @@ void VC2_PlayStop(void)
 	RVbufR1=RVbufR2=RVbufR3=RVbufR4=RVbufR5=RVbufR6=RVbufR7=RVbufR8=NULL;
 }
 
-BOOL VC2_SetNumVoices(void)
+int VC2_SetNumVoices(void)
 {
 	int t;
 
@@ -874,7 +877,7 @@ BOOL VC2_SetNumVoices(void)
 	if(!(vc_softchn=md_softchn)) return 0;
 
 	if(vinf) free(vinf);
-	if(!(vinf=_mm_calloc(sizeof(VINFO),vc_softchn))) return 1;
+	if(!(vinf=_mm_calloc(vc_softchn,sizeof(VINFO)))) return 1;
 
 	for(t=0;t<vc_softchn;t++) {
 		vinf[t].frq=10000;
